# About pymaxcul

Pymaxcul is a python package to talk to [MAX! devices by eQ-3](http://www.eq-3.de/produkte/max.html) through a [CUL stick](https://wiki.fhem.de/wiki/Selbstbau_CUL).

This module is forked from https://github.com/vogt31337/MaxCul-Python
which in turn has been at some point been forked from  https://github.com/jokey2k/MoritzServer.
It refactored to use less dependencies and to be easyly used from other projects, especially as a dependency for [Home Assistant](https://github.com/home-assistant/home-assistant).

It should be usable for thermostats but it is not well tested. As I don't have other MAX! devices I can't test and implement functionality to support them, though rudimentary support exists.
Please sent a PR if you want to add support for other devices.
